# estiloWidgets

It is a library developed in Python, to allow some modifications to some tkinter widgets that is not possible in the library originally, such as inserting "place holder" in the entry, leaving frames with gradient-style colors and simplifying the creation of buttons and labels standardized without the need to repeat settings for each widget

É uma biblioteca desenvolvida em Python, para permitir realizar algumas modificações em alguns widgets tkinter que não é possivel na biblioteca originalmente, tais como inserir "place holder" na entry, deixar os frames com cores no estilo gradiente e simplificar a criação de botoes e labels padronizadas sem necessidade de repetição de configurações a cada widget

pip install estiloWidgets

from estiloWidgets.entryPlaceHolder import *

from estiloWidgets.labelStyle import *

from estiloWidgets.gradienteFrame import *

from estiloWidgets.buttonStyle import *

GradientFrame()

LabelGlac()

ButtonGlac()

EntPlaceHold()
